@@ -1,10 +1,18 @@
 jq(document).ready(function() {
     var start_slideshow_buttons = jq(".template-gallery_view .xhostplusGalleryStartSlideshow");
+
     var slideshow_interval_time = parseInt(jq("#xhostplus_gallery_slideshow_interval").html()) * 1000;
     var slideshow_interval = null;
 
     var gallery_elements = jq(".template-gallery_view .photoAlbumEntry a").not(".template-gallery_view .photoAlbumFolder a");
     var portlet_elements = jq(".portletGallery .portletItem a");
+    var zoomable_elements = jq(".xhostplusGalleryImageZoom a").add(jq(".xhostplusGalleryImageZoom").parents("a"));
+
+    zoomable_elements.xhostplusbox({
+        'titleShow'     : true,
+        'transitionIn'  : 'elastic',
+        'transitionOut' : 'elastic'
+    });
 
     gallery_elements.xhostplusbox({
         'titleShow'     : true,
@@ -31,8 +39,8 @@ jq(document).ready(function() {
         jq("#xhostplusbox-left, #xhostplusbox-right").css({
             'visibility' : 'hidden'
         });
-        gallery_elements.first().trigger('click');
-        slideshow_interval = window.setInterval($.xhostplusbox.next, slideshow_interval_time);
+        gallery_elements.eq(0).trigger('click');
+        slideshow_interval = window.setInterval(jq.xhostplusbox.next, slideshow_interval_time);
         return false;
     });
 });
\ No newline at end of file
